<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Vivid Blog Pro
 * @since Vivid Blog Pro 1.0.0
 * @return array An array of default values
 */

function vivid_blog_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$vivid_blog_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#173857',
		'header_tagline_color'			=> '#173857',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#E73819',
		'colorscheme'					=> 'default',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( '( Read More )', 'vivid-blog-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'vivid-blog-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved', 'vivid-blog-pro' ),
		'poweredby_text'           		=> esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'vivid-blog-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,about,gallery,cta,featured,blog,quote,testimonial,subscription',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'vivid-blog-pro' ),
		'hide_date' 					=> false,
		'hide_author'					=> false,
		'hide_category'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// topbar
		'topbar_social_enable'			=> false,
		'topbar_author'					=> esc_html__( 'Alexa Bliss', 'vivid-blog-pro' ),
		'topbar_author_position'		=> esc_html__( 'Editor @ ABC', 'vivid-blog-pro' ),

		// Slider
		'slider_section_enable'			=> true,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 4,

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_sub_title'				=> esc_html__( 'Author', 'vivid-blog-pro' ),
		'about_title'					=> esc_html__( 'Welcome to the theme of Vivid Blog', 'vivid-blog-pro' ),
		'about_description'				=> esc_html__( 'The first time I ever made risotto, it was a disaster. It was straight up practically inedible. So much so that I&#39;m pretty much convinced that Mike doesn&#39;t like risotto now because of my one and only horrifying experience.', 'vivid-blog-pro' ),
		'about_btn_title'				=> esc_html__( 'Learn More', 'vivid-blog-pro' ),

		// Gallery
		'gallery_section_enable'		=> true,
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 4,

		// call to action
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'page',
		'cta_sub_title'					=> esc_html__( 'Gallery', 'vivid-blog-pro' ),
		'cta_title'						=> esc_html__( 'Delicious collection of our most memories', 'vivid-blog-pro' ),
		'cta_btn_title'					=> esc_html__( 'Read More', 'vivid-blog-pro' ),
		'cta_description'				=> esc_html__( 'The first time I ever made risotto, it was a disaster. It was straight up practically inedible. So much so that I&#39;m pretty much convinced that Mike doesn’t like risotto now because of my one and only horrifying experience. Still, I had a vision of a creamy lobster risotto with perfectly cooked slices of steak on top so I soldiered through to make this.', 'vivid-blog-pro' ),

		// Featured
		'featured_section_enable'		=> true,
		'featured_content_type'			=> 'category',
		'featured_count'				=> 4,
		'featured_btn_title'			=> esc_html__( 'Read More', 'vivid-blog-pro' ),
		
		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 8,
		'blog_title'					=> esc_html__( 'From The Blog', 'vivid-blog-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Posts', 'vivid-blog-pro' ),

		// Quote
		'quote_section_enable'			=> true,
		'quote_content_type'			=> 'category',
		'quote_count'					=> 3,
		'quote_image'					=> get_template_directory_uri() . '/assets/uploads/quote.jpg',
		'quote_sub_title'				=> esc_html__( 'Quote of the day', 'vivid-blog-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 4,
		'testimonial_title'				=> esc_html__( 'Testimonials', 'vivid-blog-pro' ),
		'testimonial_btn_title'			=> esc_html__( 'View All Testimonials', 'vivid-blog-pro' ),

		// Subscription
		'subscription_section_enable'	=> false,
		'subscription_title'			=> esc_html__( 'Don&#39;t miss any updates', 'vivid-blog-pro' ),
		'subscription_subtitle'			=> esc_html__( 'Subscribe in seconds. No requirements. Cancel anytime.', 'vivid-blog-pro' ),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'vivid-blog-pro' ),
		'subscription_image'			=> get_template_directory_uri() . '/assets/uploads/subscribe.jpg',

	);

	$output = apply_filters( 'vivid_blog_pro_default_theme_options', $vivid_blog_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}