<?php
/**
 * Quote Section options
 *
 * @package Theme Palace
 * @subpackage Vivid Blog Pro
 * @since Vivid Blog Pro 1.0.0
 */

// Add Quote section
$wp_customize->add_section( 'vivid_blog_pro_quote_section', array(
	'title'             => esc_html__( 'Quote','vivid-blog-pro' ),
	'description'       => esc_html__( 'Quote Section options.', 'vivid-blog-pro' ),
	'panel'             => 'vivid_blog_pro_front_page_panel',
) );

// Quote content enable control and setting
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[quote_section_enable]', array(
	'default'			=> 	$options['quote_section_enable'],
	'sanitize_callback' => 'vivid_blog_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Vivid_Blog_Pro_Switch_Control( $wp_customize, 'vivid_blog_pro_theme_options[quote_section_enable]', array(
	'label'             => esc_html__( 'Quote Section Enable', 'vivid-blog-pro' ),
	'section'           => 'vivid_blog_pro_quote_section',
	'on_off_label' 		=> vivid_blog_pro_switch_options(),
) ) );

// quote btn title setting and control
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[quote_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['quote_sub_title'],
) );

$wp_customize->add_control( 'vivid_blog_pro_theme_options[quote_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'vivid-blog-pro' ),
	'section'        	=> 'vivid_blog_pro_quote_section',
	'active_callback' 	=> 'vivid_blog_pro_is_quote_section_enable',
	'type'				=> 'text',
) );

// quote image setting and control.
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[quote_image]', array(
	'default'          	=> $options['quote_image'],
	'sanitize_callback' => 'vivid_blog_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'vivid_blog_pro_theme_options[quote_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'vivid-blog-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'vivid-blog-pro' ), 1920, 854 ),
		'section'     		=> 'vivid_blog_pro_quote_section',
		'active_callback'	=> 'vivid_blog_pro_is_quote_section_enable',
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[quote_count]', array(
	'default'          	=> $options['quote_count'],
	'sanitize_callback' => 'vivid_blog_pro_sanitize_number_range',
	'validate_callback' => 'vivid_blog_pro_validate_quote_count',
) );

$wp_customize->add_control( 'vivid_blog_pro_theme_options[quote_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'vivid-blog-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'vivid-blog-pro' ),
	'section'           => 'vivid_blog_pro_quote_section',
	'active_callback'   => 'vivid_blog_pro_is_quote_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Quote content type control and setting
$wp_customize->add_setting( 'vivid_blog_pro_theme_options[quote_content_type]', array(
	'default'          	=> $options['quote_content_type'],
	'sanitize_callback' => 'vivid_blog_pro_sanitize_select',
) );

$wp_customize->add_control( 'vivid_blog_pro_theme_options[quote_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'vivid-blog-pro' ),
	'section'           => 'vivid_blog_pro_quote_section',
	'type'				=> 'select',
	'active_callback' 	=> 'vivid_blog_pro_is_quote_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'vivid-blog-pro' ),
		'post' 		=> esc_html__( 'Post', 'vivid-blog-pro' ),
		'category' 	=> esc_html__( 'Category', 'vivid-blog-pro' ),
	),
) );

for ( $i = 1; $i <= $options['quote_count']; $i++ ) :
	// quote pages drop down chooser control and setting
	$wp_customize->add_setting( 'vivid_blog_pro_theme_options[quote_content_page_' . $i . ']', array(
		'sanitize_callback' => 'vivid_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Vivid_Blog_Pro_Dropdown_Chooser( $wp_customize, 'vivid_blog_pro_theme_options[quote_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'vivid-blog-pro' ), $i ),
		'section'           => 'vivid_blog_pro_quote_section',
		'choices'			=> vivid_blog_pro_page_choices(),
		'active_callback'	=> 'vivid_blog_pro_is_quote_section_content_page_enable',
	) ) );

	// quote posts drop down chooser control and setting
	$wp_customize->add_setting( 'vivid_blog_pro_theme_options[quote_content_post_' . $i . ']', array(
		'sanitize_callback' => 'vivid_blog_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Vivid_Blog_Pro_Dropdown_Chooser( $wp_customize, 'vivid_blog_pro_theme_options[quote_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'vivid-blog-pro' ), $i ),
		'section'           => 'vivid_blog_pro_quote_section',
		'choices'			=> vivid_blog_pro_post_choices(),
		'active_callback'	=> 'vivid_blog_pro_is_quote_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'vivid_blog_pro_theme_options[quote_content_category]', array(
	'sanitize_callback' => 'vivid_blog_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Vivid_Blog_Pro_Dropdown_Taxonomies_Control( $wp_customize,'vivid_blog_pro_theme_options[quote_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'vivid-blog-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'vivid-blog-pro' ),
	'section'           => 'vivid_blog_pro_quote_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'vivid_blog_pro_is_quote_section_content_category_enable'
) ) );
